@@ -129,7 +129,7 @@ static struct volume_group *_build_vg_from_pds(struct format_instance
 	if (!import_pool_vg(vg, smem, pds))
 		return_NULL;
 
-	if (!import_pool_pvs(fid->fmt, vg, &vg->pvs, smem, pds))
+	if (!import_pool_pvs(fid->fmt, vg, smem, pds))
 		return_NULL;
 
 	if (!import_pool_lvs(vg, smem, pds))
@@ -262,7 +262,8 @@ static struct format_instance *_pool_create_instance(const struct format_type *f
 	}
 
 	fid->fmt = fmt;
-	dm_list_init(&fid->metadata_areas);
+	dm_list_init(&fid->metadata_areas_in_use);
+	dm_list_init(&fid->metadata_areas_ignored);
 
 	/* Define a NULL metadata area */
 	if (!(mda = dm_pool_zalloc(fmt->cmd->mem, sizeof(*mda)))) {
@@ -274,7 +275,8 @@ static struct format_instance *_pool_create_instance(const struct format_type *f
 
 	mda->ops = &_metadata_format_pool_ops;
 	mda->metadata_locn = NULL;
-	dm_list_add(&fid->metadata_areas, &mda->list);
+	mda->flags = 0;
+	dm_list_add(&fid->metadata_areas_in_use, &mda->list);
 
 	return fid;
 }
