@@ -842,7 +842,8 @@ static int _udevflags(int args, char **argv, void *data __attribute((unused)))
 					      "DISABLE_OTHER_RULES",
 					      "LOW_PRIORITY",
 					      "DISABLE_LIBRARY_FALLBACK",
-					       0, 0};
+					      "PRIMARY_SOURCE",
+					       0};
 
 	if (!(cookie = _get_cookie_value(argv[1])))
 		return 0;
@@ -2941,7 +2942,7 @@ static int _loop_table(char *table, size_t tlen, char *file,
 	close(fd);
 
 	if (dm_snprintf(table, tlen, "%llu %llu loop %s %llu\n", 0ULL,
-			(long long unsigned)sectors, file, off) < 0)
+			(long long unsigned)sectors, file, (long long unsigned)off) < 0)
 		return 0;
 
 	if (_switches[VERBOSE_ARG] > 1)
@@ -2955,8 +2956,6 @@ error:
 	return 0;
 }
 
-
-
 static int _process_losetup_switches(const char *base, int *argc, char ***argv,
 				     const char *dev_dir)
 {
