@@ -705,9 +705,12 @@ static int _lv_update_mirrored_log(struct logical_volume *lv,
 		return 1;
 
 	/* Reducing redundancy of the log */
-	return remove_mirror_images(log_lv, log_count,
-				    is_mirror_image_removable,
-				    operable_pvs, 0U);
+	if (log_count)
+		return remove_mirror_images(log_lv, log_count,
+					    is_mirror_image_removable,
+					    operable_pvs, 0U);
+
+	return remove_mirror_log(lv->vg->cmd, lv, operable_pvs);
 }
 
 static int _lv_update_log_type(struct cmd_context *cmd,
@@ -790,7 +793,6 @@ static void _remove_missing_empty_pv(struct volume_group *vg, struct dm_list *re
 			stack;
 			return;
 		}
-
 		log_warn("%d missing and now unallocated Physical Volumes removed from VG.", removed);
 	}
 }
@@ -1177,7 +1179,6 @@ static int _lvconvert_mirrors_repair(struct cmd_context *cmd,
 	int replace_log = 0;
 	int replace_mirrors = 0;
 	uint32_t new_log_count, log_count;
-	struct dm_list *failed_pvs = NULL;
 	struct logical_volume *log_lv;
 
 	cmd->handles_missing_pvs = 1;
@@ -1232,14 +1233,14 @@ static int _lvconvert_mirrors_repair(struct cmd_context *cmd,
 	/*
 	 * First phase - remove faulty devices
 	 */
-	if (!(failed_pvs = _failed_pv_list(lv->vg)))
+	if (!(lp->failed_pvs = _failed_pv_list(lv->vg)))
 		return_0;
 
 	/*
 	 * We must adjust the log first, or the entire mirror
 	 * will get stuck during a suspend.
 	 */
-	if (!_lv_update_mirrored_log(lv, failed_pvs, new_log_count))
+	if (!_lv_update_mirrored_log(lv, lp->failed_pvs, new_log_count))
 		return 0;
 
 	if (lp->mirrors == 1)
@@ -1252,7 +1253,7 @@ static int _lvconvert_mirrors_repair(struct cmd_context *cmd,
 			return 0;
 	}
 
-	if (!_lv_update_log_type(cmd, lp, lv, failed_pvs,
+	if (!_lv_update_log_type(cmd, lp, lv, lp->failed_pvs,
 				 new_log_count))
 		return 0;
 
